==> plf-community-tomcat-standalone-4.0.6.zip: com/smartgwt/client/docs/Sizing.java <==

package com.smartgwt.client.docs;

/**
 * Width and height of an object
 * @see com.smartgwt.client.widgets.form.fields.FormItem#getRect
 * @see com.smartgwt.client.widgets.form.fields.FormItem#getPageRect
 * @see com.smartgwt.client.widgets.form.fields.FormItem#getVisibleHeight
 * @see com.smartgwt.client.widgets.form.fields.FormItem#getIconHeight
 * @see com.smartgwt.client.widgets.form.fields.FormItem#getWidth
 * @see com.smartgwt.client.widgets.form.fields.FormItem#getVisibleWidth
 * @see com.smartgwt.client.widgets.form.fields.FormItem#getIconWidth
 * @see com.smartgwt.client.widgets.form.fields.FormItem#getLeft
 * @see com.smartgwt.client.widgets.form.fields.FormItem#getTop
 * @see com.smartgwt.client.widgets.grid.ListGrid#getDrawnRowHeight
 * @see com.smartgwt.client.widgets.grid.ListGrid#setHeaderHeight
 * @see com.smartgwt.client.widgets.Canvas#setRect
 * @see com.smartgwt.client.widgets.Canvas#getWidth
 * @see com.smartgwt.client.widgets.Canvas#setWidth
 * @see com.smartgwt.client.widgets.Canvas#getHeight
 * @see com.smartgwt.client.widgets.Canvas#setHeight
 * @see com.smartgwt.client.widgets.Canvas#getRight
 * @see com.smartgwt.client.widgets.Canvas#setRight
 * @see com.smartgwt.client.widgets.Canvas#getBottom
 * @see com.smartgwt.client.widgets.Canvas#setBottom
 * @see com.smartgwt.client.widgets.Canvas#getScrollWidth
 * @see com.smartgwt.client.widgets.Canvas#getScrollHeight
 * @see com.smartgwt.client.widgets.Canvas#getViewportWidth
 * @see com.smartgwt.client.widgets.Canvas#getViewportHeight
 * @see com.smartgwt.client.widgets.Canvas#getInnerHeight
 * @see com.smartgwt.client.widgets.Canvas#getInnerWidth
 * @see com.smartgwt.client.widgets.Canvas#getInnerContentHeight
 * @see com.smartgwt.client.widgets.Canvas#getInnerContentWidth
 * @see com.smartgwt.client.widgets.Canvas#getVisibleWidth
 * @see com.smartgwt.client.widgets.Canvas#getVisibleHeight
 * @see com.smartgwt.client.widgets.Canvas#resizeBy
 * @see com.smartgwt.client.widgets.Canvas#setPercentSource
 * @see com.smartgwt.client.widgets.Canvas#layoutChildren
 * @see com.smartgwt.client.widgets.Canvas#resizeTo
 * @see com.smartgwt.client.widgets.Canvas#parentResized
 * @see com.smartgwt.client.widgets.Canvas#setOverflow
 * @see com.smartgwt.client.widgets.Canvas#adjustForContent
 * @see com.smartgwt.client.util.Page#resizeTo
 * @see com.smartgwt.client.util.Page#getWidth
 * @see com.smartgwt.client.util.Page#getHeight
 * @see com.smartgwt.client.util.Page#getScrollWidth
 * @see com.smartgwt.client.util.Page#getScrollHeight
 * @see com.smartgwt.client.util.Page#getScrollLeft
 * @see com.smartgwt.client.util.Page#getScrollTop
 * @see com.smartgwt.client.grid.GridRenderer#getFixedColumnWidths
 * @see com.smartgwt.client.grid.GridRenderer#getAutoFit
 * @see com.smartgwt.client.widgets.grid.ListGrid#getBodyOverflow
 * @see com.smartgwt.client.widgets.grid.ListGrid#getHeaderHeight
 * @see com.smartgwt.client.widgets.menu.Menu#getDefaultWidth
 * @see com.smartgwt.client.widgets.menu.Menu#getCellHeight
 * @see com.smartgwt.client.widgets.tile.TileLayout#getTileSize
 * @see com.smartgwt.client.widgets.tile.TileLayout#getTileWidth
 * @see com.smartgwt.client.widgets.tile.TileLayout#getTileHeight
 * @see com.smartgwt.client.widgets.tile.TileLayout#getOverflow
 * @see com.smartgwt.client.widgets.Canvas#getWidth
 * @see com.smartgwt.client.widgets.Canvas#getHeight
 * @see com.smartgwt.client.widgets.Canvas#getDefaultWidth
 * @see com.smartgwt.client.widgets.Canvas#getDefaultHeight
 * @see com.smartgwt.client.widgets.Canvas#getMinWidth
 * @see com.smartgwt.client.widgets.Canvas#getMaxWidth
 * @see com.smartgwt.client.widgets.Canvas#getMinHeight
 * @see com.smartgwt.client.widgets.Canvas#getMaxHeight
 * @see com.smartgwt.client.widgets.Canvas#getOverflow
 * @see com.smartgwt.client.widgets.Canvas#getPercentSource
 * @see com.smartgwt.client.widgets.Canvas#getPercentBox
 * @see com.smartgwt.client.widgets.Canvas#getSnapTo
 * @see com.smartgwt.client.widgets.Canvas#getSnapEdge
 * @see com.smartgwt.client.widgets.Canvas#getSnapOffsetLeft
 * @see com.smartgwt.client.widgets.Canvas#getSnapOffsetTop
 * @see com.smartgwt.client.widgets.StatefulCanvas#getAutoFit
 * @see com.smartgwt.client.widgets.Button#getAutoFit
 * @see com.smartgwt.client.widgets.Img#getSize
 * @see com.smartgwt.client.widgets.Label#getWrap
 * @see com.smartgwt.client.widgets.Label#getAutoFit
 * @see com.smartgwt.client.widgets.ImgButton#getAutoFit
 * @see com.smartgwt.client.widgets.StretchImgButton#getAutoFit
 * @see com.smartgwt.client.widgets.toolbar.ToolStrip#getHeight
 * @see com.smartgwt.client.types.Overflow
 */
public interface Sizing {
}

==> plf-community-tomcat-standalone-4.4.3.zip: com/smartgwt/client/docs/Sizing.java <==

package com.smartgwt.client.docs;

/**
 * Width and height of an object
 * @see com.smartgwt.client.types.Overflow
 * @see com.smartgwt.client.util.Page#resizeTo
 * @see com.smartgwt.client.util.Page#getWidth
 * @see com.smartgwt.client.util.Page#getHeight
 * @see com.smartgwt.client.util.Page#getScrollWidth
 * @see com.smartgwt.client.util.Page#getScrollHeight
 * @see com.smartgwt.client.util.Page#getScrollLeft
 * @see com.smartgwt.client.util.Page#getScrollTop
 * @see com.smartgwt.client.widgets.layout.Portlet#setHeight
 * @see com.smartgwt.client.widgets.layout.Portlet#setRowHeight
 * @see com.smartgwt.client.widgets.layout.PortalLayout#setCanStretchColumnWidths
 * @see com.smartgwt.client.widgets.layout.PortalLayout#setCanShrinkColumnWidths
 * @see com.smartgwt.client.widgets.layout.PortalLayout#setStretchColumnWidthsProportionally
 * @see com.smartgwt.client.widgets.layout.PortalLayout#setPreventUnderflow
 * @see com.smartgwt.client.widgets.layout.PortalLayout#setColumnPreventUnderflow
 * @see com.smartgwt.client.widgets.layout.PortalLayout#setPreventRowUnderflow
 * @see com.smartgwt.client.widgets.layout.PortalLayout#setCanResizeColumns
 * @see com.smartgwt.client.widgets.layout.PortalLayout#setCanResizePortlets
 * @see com.smartgwt.client.widgets.Canvas#setRect
 * @see com.smartgwt.client.widgets.Canvas#getWidth
 * @see com.smartgwt.client.widgets.Canvas#setWidth
 * @see com.smartgwt.client.widgets.Canvas#getHeight
 * @see com.smartgwt.client.widgets.Canvas#setHeight
 * @see com.smartgwt.client.widgets.Canvas#getRight
 * @see com.smartgwt.client.widgets.Canvas#setRight
 * @see com.smartgwt.client.widgets.Canvas#getBottom
 * @see com.smartgwt.client.widgets.Canvas#setBottom
 * @see com.smartgwt.client.widgets.Canvas#getScrollWidth
 * @see com.smartgwt.client.widgets.Canvas#getScrollHeight
 * @see com.smartgwt.client.widgets.Canvas#getViewportWidth
 * @see com.smartgwt.client.widgets.Canvas#getViewportHeight
 * @see com.smartgwt.client.widgets.Canvas#getInnerHeight
 * @see com.smartgwt.client.widgets.Canvas#getInnerWidth
 * @see com.smartgwt.client.widgets.Canvas#getInnerContentHeight
 * @see com.smartgwt.client.widgets.Canvas#getInnerContentWidth
 * @see com.smartgwt.client.widgets.Canvas#getVisibleWidth
 * @see com.smartgwt.client.widgets.Canvas#getVisibleHeight
 * @see com.smartgwt.client.widgets.Canvas#resizeBy
 * @see com.smartgwt.client.widgets.Canvas#setPercentSource
 * @see com.smartgwt.client.widgets.Canvas#layoutChildren
 * @see com.smartgwt.client.widgets.Canvas#resizeTo
 * @see com.smartgwt.client.widgets.Canvas#parentResized
 * @see com.smartgwt.client.widgets.Canvas#setOverflow
 * @see com.smartgwt.client.widgets.Canvas#adjustForContent
 * @see com.smartgwt.client.widgets.form.fields.FormItem#getRect
 * @see com.smartgwt.client.widgets.form.fields.FormItem#getPageRect
 * @see com.smartgwt.client.widgets.form.fields.FormItem#getVisibleHeight
 * @see com.smartgwt.client.widgets.form.fields.FormItem#getIconHeight
 * @see com.smartgwt.client.widgets.form.fields.FormItem#getWidth
 * @see com.smartgwt.client.widgets.form.fields.FormItem#getVisibleWidth
 * @see com.smartgwt.client.widgets.form.fields.FormItem#getVisibleTitleWidth
 * @see com.smartgwt.client.widgets.form.fields.FormItem#getIconWidth
 * @see com.smartgwt.client.widgets.form.fields.FormItem#getLeft
 * @see com.smartgwt.client.widgets.form.fields.FormItem#getTop
 * @see com.smartgwt.client.widgets.grid.ListGrid#getColumnLeft
 * @see com.smartgwt.client.widgets.grid.ListGrid#getColumnPageLeft
 * @see com.smartgwt.client.widgets.grid.ListGrid#getColumnWidth
 * @see com.smartgwt.client.widgets.grid.ListGrid#getCellPageRect
 * @see com.smartgwt.client.widgets.grid.ListGrid#getDrawnRowHeight
 * @see com.smartgwt.client.widgets.grid.ListGrid#setHeaderHeight
 * @see com.smartgwt.client.widgets.layout.Portlet#getRowHeight
 * @see com.smartgwt.client.widgets.layout.PortalLayout#getOverflow
 * @see com.smartgwt.client.widgets.layout.PortalLayout#getColumnOverflow
 * @see com.smartgwt.client.widgets.layout.PortalLayout#getCanStretchColumnWidths
 * @see com.smartgwt.client.widgets.layout.PortalLayout#getCanShrinkColumnWidths
 * @see com.smartgwt.client.widgets.layout.PortalLayout#getStretchColumnWidthsProportionally
 * @see com.smartgwt.client.widgets.layout.PortalLayout#getPreventUnderflow
 * @see com.smartgwt.client.widgets.layout.PortalLayout#getPreventColumnUnderflow
 * @see com.smartgwt.client.widgets.layout.PortalLayout#getPreventRowUnderflow
 * @see com.smartgwt.client.widgets.layout.PortalLayout#getCanResizeColumns
 * @see com.smartgwt.client.widgets.layout.PortalLayout#getCanResizePortlets
 * @see com.smartgwt.client.widgets.Canvas#getWidth
 * @see com.smartgwt.client.widgets.Canvas#getHeight
 * @see com.smartgwt.client.widgets.Canvas#getDefaultWidth
 * @see com.smartgwt.client.widgets.Canvas#getDefaultHeight
 * @see com.smartgwt.client.widgets.Canvas#getMinWidth
 * @see com.smartgwt.client.widgets.Canvas#getMinHeight
 * @see com.smartgwt.client.widgets.Canvas#getMaxWidth
 * @see com.smartgwt.client.widgets.Canvas#getMaxHeight
 * @see com.smartgwt.client.widgets.Canvas#getDragMinWidth
 * @see com.smartgwt.client.widgets.Canvas#getDragMinHeight
 * @see com.smartgwt.client.widgets.Canvas#getDragMaxWidth
 * @see com.smartgwt.client.widgets.Canvas#getDragMaxHeight
 * @see com.smartgwt.client.widgets.Canvas#getOverflow
 * @see com.smartgwt.client.widgets.Canvas#getPercentSource
 * @see com.smartgwt.client.widgets.Canvas#getPercentBox
 * @see com.smartgwt.client.widgets.Canvas#getSnapTo
 * @see com.smartgwt.client.widgets.Canvas#getSnapEdge
 * @see com.smartgwt.client.widgets.Canvas#getSnapOffsetLeft
 * @see com.smartgwt.client.widgets.Canvas#getSnapOffsetTop
 * @see com.smartgwt.client.widgets.StatefulCanvas#getAutoFit
 * @see com.smartgwt.client.widgets.Button#getAutoFit
 * @see com.smartgwt.client.widgets.Img#getSize
 * @see com.smartgwt.client.widgets.Label#getWrap
 * @see com.smartgwt.client.widgets.Label#getAutoFit
 * @see com.smartgwt.client.widgets.ImgButton#getAutoFit
 * @see com.smartgwt.client.widgets.StretchImgButton#getAutoFit
 * @see com.smartgwt.client.widgets.toolbar.ToolStrip#getHeight
 * @see com.smartgwt.client.widgets.grid.ListGrid#getBodyOverflow
 * @see com.smartgwt.client.widgets.grid.ListGrid#getHeaderHeight
 * @see com.smartgwt.client.widgets.menu.Menu#getDefaultWidth
 * @see com.smartgwt.client.widgets.menu.Menu#getCellHeight
 * @see com.smartgwt.client.widgets.tile.TileLayout#getTileSize
 * @see com.smartgwt.client.widgets.tile.TileLayout#getTileWidth
 * @see com.smartgwt.client.widgets.tile.TileLayout#getTileHeight
 * @see com.smartgwt.client.widgets.tile.TileLayout#getOverflow
 */
public interface Sizing {
}
